@@ -8,7 +8,7 @@
 /*                           Interdisciplinary Graduate School of    */
 /*                           Science and Engineering                 */
 /*                                                                   */
-/*                1996-2013  Nagoya Institute of Technology          */
+/*                1996-2014  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -69,13 +69,13 @@
 *               data sequence                                   [stdin] *
 *       stdout:                                                         *
 *               cut data sequence                                       *
-*       note:                                                           *
+*       notice:                                                         *
 *               When both -l and -n are specified,                      *
 *               latter argument is adopted.                             *
 *                                                                       *
 ************************************************************************/
 
-static char *rcs_id = "$Id: bcut.c,v 1.30 2013/12/16 09:01:54 mataki Exp $";
+static char *rcs_id = "$Id: bcut.c,v 1.32 2014/12/11 08:30:31 uratec Exp $";
 
 
 /*  Standard C Libraries  */
@@ -153,7 +153,7 @@ void usage(int status)
    fprintf(stderr, "       data sequence        [stdin]\n");
    fprintf(stderr, "  stdout:\n");
    fprintf(stderr, "       cut data sequence\n");
-   fprintf(stderr, "  note:\n");
+   fprintf(stderr, "  notice:\n");
    fprintf(stderr, "       When both -l and -n are specified,\n");
    fprintf(stderr, "       latter argument is adopted.\n");
 #ifdef PACKAGE_VERSION
