@@ -8,7 +8,7 @@
 /*                           Interdisciplinary Graduate School of    */
 /*                           Science and Engineering                 */
 /*                                                                   */
-/*                1996-2013  Nagoya Institute of Technology          */
+/*                1996-2014  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -44,7 +44,7 @@
 
 /****************************************************************
 
-    $Id: _gmm.c,v 1.20 2013/12/16 09:01:57 mataki Exp $
+    $Id: _gmm.c,v 1.22 2014/12/11 08:30:36 uratec Exp $
 
     GMM output prob calculation functions
 
@@ -326,8 +326,6 @@ int load_GMM(GMM * gmm, FILE * fp)
             freadf(gmm->gauss[m].cov[l],
                    sizeof(*(gmm->gauss[m].cov[l])), gmm->dim, fp);
          }
-         invert(gmm->gauss[m].cov, gmm->gauss[m].inv, gmm->dim);
-         gmm->gauss[m].gconst = cal_gconstf(gmm->gauss[m].cov, gmm->dim);
       }
    }
 
@@ -362,6 +360,80 @@ int save_GMM(const GMM * gmm, FILE * fp)
    return (0);
 }
 
+int prepareCovInv_GMM(GMM * gmm)
+{
+   int m;
+   for (m = 0; m < gmm->nmix; m++) {
+      cal_inv(gmm->gauss[m].cov, gmm->gauss[m].inv, gmm->dim);
+   }
+
+   return (0);
+}
+
+int prepareGconst_GMM(GMM * gmm)
+{
+   int m;
+
+   for (m = 0; m < gmm->nmix; m++) {
+      if (gmm->full == FA) {
+         gmm->gauss[m].gconst = cal_gconst(gmm->gauss[m].var, gmm->dim);
+      } else {
+         gmm->gauss[m].gconst = cal_gconstf(gmm->gauss[m].cov, gmm->dim);
+      }
+      if (gmm->gauss[m].gconst == 0) {
+         return -1;
+      }
+   }
+
+   return (0);
+}
+
+int floorWeight_GMM(GMM * gmm, double floor)
+{
+   int m;
+   double sum_w = 0.0, sum_floor = floor * gmm->nmix;
+
+   for (m = 0; m < gmm->nmix; m++) {
+      if (gmm->weight[m] < floor) {
+         gmm->weight[m] = floor;
+      }
+      sum_w += gmm->weight[m];
+   }
+   if (sum_w != 1.0) {
+      for (m = 0; m < gmm->nmix; m++) {
+         gmm->weight[m] =
+             (1.0 - sum_floor) / (sum_w - sum_floor) * (gmm->weight[m] -
+                                                        floor) + floor;
+      }
+   }
+
+   return (0);
+}
+
+int floorVar_GMM(GMM * gmm, double floor)
+{
+   int m, l;
+   if (gmm->full == FA) {
+      for (m = 0; m < gmm->nmix; m++) {
+         for (l = 0; l < gmm->dim; l++) {
+            if (gmm->gauss[m].var[l] < floor) {
+               gmm->gauss[m].var[l] = floor;
+            }
+         }
+      }
+   } else {
+      for (m = 0; m < gmm->nmix; m++) {
+         for (l = 0; l < gmm->dim; l++) {
+            if (gmm->gauss[m].cov[l][l] < floor) {
+               gmm->gauss[m].cov[l][l] = floor;
+            }
+         }
+      }
+   }
+
+   return (0);
+}
+
 int free_GMM(GMM * gmm)
 {
    int m;
