@@ -8,7 +8,7 @@
 /*                           Interdisciplinary Graduate School of    */
 /*                           Science and Engineering                 */
 /*                                                                   */
-/*                1996-2013  Nagoya Institute of Technology          */
+/*                1996-2014  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -54,7 +54,7 @@
 *               -m m     :  order of LSP                [25]            *
 *               -s s     :  sampling frequency          [10]            *
 *               -k       :  input & output gain         [FALSE]         *
-*               -i i     :  input format                [0]             *
+*               -q q     :  input format                [0]             *
 *               -o o     :  output format               [i]             *
 *                             0 (normalized frequency <0...pi>)         *
 *                             1 (normalized frequency <0...0.5>)        *
@@ -79,7 +79,7 @@
 *                                                                       *
 ************************************************************************/
 
-static char *rcs_id = "$Id: lspcheck.c,v 1.37 2013/12/19 02:28:27 mataki Exp $";
+static char *rcs_id = "$Id: lspcheck.c,v 1.41 2014/12/25 02:41:38 uratec Exp $";
 
 
 /*  Standard C Libraries  */
@@ -138,7 +138,7 @@ void usage(int status)
            "       -k    : input & output gain                        [%s]\n",
            BOOL[GAIN]);
    fprintf(stderr,
-           "       -i i  : input format                               [%d]\n",
+           "       -q q  : input format                               [%d]\n",
            ITYPE);
    fprintf(stderr,
            "       -o o  : output format                              [i]\n");
@@ -210,6 +210,7 @@ int main(int argc, char **argv)
             --argc;
             break;
          case 'i':
+         case 'q':
             itype = atoi(*++argv);
             --argc;
             break;
