@@ -8,7 +8,7 @@
 /*                           Interdisciplinary Graduate School of    */
 /*                           Science and Engineering                 */
 /*                                                                   */
-/*                1996-2013  Nagoya Institute of Technology          */
+/*                1996-2014  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -72,7 +72,7 @@
 *                                                                                       *
 ****************************************************************************************/
 
-static char *rcs_id = "$Id: mlpg.c,v 1.34 2013/12/16 09:02:01 mataki Exp $";
+static char *rcs_id = "$Id: mlpg.c,v 1.36 2014/12/11 08:30:42 uratec Exp $";
 
 
 /* Standard C Libraries */
@@ -212,7 +212,7 @@ void usage(int status)
            "       PDF sequence                                                     [stdin]\n");
    fprintf(stderr, "  stdout:\n");
    fprintf(stderr, "       parameter sequence\n");
-   fprintf(stderr, "  note:\n");
+   fprintf(stderr, "  notice:\n");
    fprintf(stderr,
            "       1) Option '-d' may be repeated to use multiple delta parameters.\n");
    fprintf(stderr,
