@@ -1,26 +1,28 @@
-/* Copyright (c) 2009-2011 Kyle Gorman
+/* Copyright (c) 2009-2013 Kyle Gorman
  *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to 
- * deal in the Software without restriction, including without limitation the 
- * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or 
- * sell copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in
- * all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
- * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
- * IN THE SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a 
+ * copy of this software and associated documentation files (the 
+ * "Software"), to deal in the Software without restriction, including 
+ * without limitation the rights to use, copy, modify, merge, publish, 
+ * distribute, sublicense, and/or sell copies of the Software, and to 
+ * permit persons to whom the Software is furnished to do so, subject to 
+ * the following conditions:
+ * 
+ * The above copyright notice and this permission notice shall be included 
+ * in all copies or substantial portions of the Software.
+ * 
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
+ * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
+ * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY 
+ * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
+ * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
+ * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  * 
  * swipe.c: primary functions
- * Kyle Gorman
+ * Kyle Gorman <gormanky@ohsu.edu>
  */
+
 /* ----------------------------------------------------------------- */
 /*             The Speech Signal Processing Toolkit (SPTK)           */
 /*             developed by SPTK Working Group                       */
@@ -31,7 +33,7 @@
 /*                           Interdisciplinary Graduate School of    */
 /*                           Science and Engineering                 */
 /*                                                                   */
-/*                1996-2013  Nagoya Institute of Technology          */
+/*                1996-2014  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -65,34 +67,15 @@
 /* POSSIBILITY OF SUCH DAMAGE.                                       */
 /* ----------------------------------------------------------------- */
 
-/****************************************************************
-
-    $Id: swipe.c,v 1.10 2013/12/16 09:02:02 mataki Exp $
-
-*****************************************************************/
-
-#define VNUM    1.4 // Current version
-#if 0
-#else
-#if defined(WIN32)
-  #define _USE_MATH_DEFINES
-#endif
-#endif
+#define VNUM    1.5 // current version
 
 #include <math.h>
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#if 0
 #include <unistd.h>
-#else
-#if defined(WIN32)
-#  include <windows.h>
-#else
-#  include <unistd.h>
-#endif
-#endif
 #include <limits.h>
+#include <stdbool.h>
 
 #if 0
 #include <fftw3.h>   // http://www.fftw.org/
@@ -101,19 +84,21 @@
 
 #include "vector.h"  // comes with release
 
-#define NOK     0
+#define NOK      0
 
-#define TRUE    1
-#define FALSE   0
+#define DERBS    .1 
+#define POLYV    .0013028 //  1 / 12 / 64 = 1 / 768
+#define DLOG2P   .0104167 // 1/96
 
-#define DERBS   .1 
-#define POLYV   .0013028 //  1 / 12 / 64 = 1 / 768
-#define DLOG2P  .0104167 // 1/96
+// feel free to change these defaults
+#define ST       .3  
+#define DT       .001
+#define MIN      100.
+#define MAX      600.
 
-#define ST      .3  // Feel free to change these
-#define DT      .001
-#define MIN     100.
-#define MAX     600.
+#ifndef M_PI
+    #define M_PI 3.14159265358979323846
+#endif
 
 #ifndef NAN
     #define NAN sqrt(-1.)
@@ -126,91 +111,79 @@ int isnan(double x) {
 #endif
 
 #ifndef log2
-double log2(double x) { // A base-2 log function
+// a base-2 log function
+double log2(double x) { 
     return log(x) / log(2.);
 }
 #endif
 
 #ifndef round
-double round(double x) { // Rounds a double to the nearest integer value
+// rounds a double to the nearest integer value
+double round(double x) { 
     return(x >= 0. ? floor(x + .5) : floor(x - .5));
 }
 #endif
 
-double hz2mel(double hz) { // Converts from hertz to Mel frequency
+// converts from hertz to Mel frequency
+double hz2mel(double hz) { 
     return(1127.01048 * log(1. + hz / 700.));
 }
 
-double hz2erb(double hz) { // Converts from hertz to ERBs
+// converts from hertz to ERBs
+double hz2erb(double hz) { 
     return(21.4 * log10(1. + hz / 229.));
 }
 
-double erb2hz(double erb) { // Converts from ERBs to hertz 
+// converts from ERBs to hertz 
+double erb2hz(double erb) { 
     return((pow(10, erb / 21.4) - 1.) * 229.);
 }
 
-double fixnan(double x) { // A silly function that treats NaNs as 0.
+// a silly function that treats NaNs as 0.
+double fixnan(double x) { 
     return(isnan(x) ? 0. : x);
 }
 
-#if 0
-#else
+#if 1
 typedef double out_complex[2];
 typedef struct _float_list {
     float f;
     struct _float_list *next;
 } float_list;
-#endif
-
-#if 0
-#else
 int fftr(double *x, double *y, const int m);
 int fwritef(double *ptr, const size_t size, const int nitems, FILE * fp);
 #endif
 
+// a helper function for loudness() for individual fft slices
 #if 0
-// A helper function for loudness() for individual fft slices
 void La(matrix L, vector f, vector fERBs, fftw_plan plan, 
-                                   fftw_complex* fo, int w2, int hi, int i) {
+                            fftw_complex* fo, int w2, int hi, int i) {
     int j;
     fftw_execute(plan);
 #else
-void La(matrix L, vector f, vector fERBs, 
+void La(matrix L, vector f, vector fERBs,
 	out_complex* fo, int w2, int hi, int i, double* fi) {
     int j;
 
     double* fi_tmp = malloc(sizeof(double) * w2*2);
-    double* fo_tmp = malloc(sizeof(double) * w2*2); 
-    vector a, a2;
+    double* fo_tmp = malloc(sizeof(double) * w2*2);
     for(j=0;j<w2 * 2;j++){
       fi_tmp[j] = fi[j];
     }
-
     fftr(fi_tmp,fo_tmp,w2*2);
-
     for(j=0;j<w2*2;j++){
       fo[j][0] = fi_tmp[j];
       fo[j][1] = fo_tmp[j];
     }
     free(fi_tmp);
     free(fo_tmp);
-
 #endif
-#if 0
     vector a = makev(w2);
-#else
-    a = makev(w2);
-#endif
-    for (j = 0; j < w2; j++) { // This iterates over only the first half
+    for (j = 0; j < w2; j++) // this iterates over only the first half
         a.v[j] = sqrt(fo[j][0] * fo[j][0] + fo[j][1] * fo[j][1]);
-    }
-#if 0
     vector a2 = spline(f, a); // a2 is now the result of the cubic spline
-#else
-    a2 = spline(f, a);
-#endif
     L.m[i][0] = fixnan(sqrt(splinv(f, a, a2, fERBs.v[0], hi)));
-    for (j = 1; j < L.y; j++) { // Perform a bisection query at ERB intervals
+    for (j = 1; j < L.y; j++) { // perform a bisection query at ERB intvls
         hi = bilookv(f, fERBs.v[j], hi); 
         L.m[i][j] = fixnan(sqrt(splinv(f, a, a2, fERBs.v[j], hi)));
     }
@@ -218,85 +191,71 @@ void La(matrix L, vector f, vector fERBs,
     freev(a2);
 }
 
-//  A function for populating the loudness matrix with a signal x
-matrix loudness(vector x, vector fERBs, double nyquist, int w, int w2) { // L
-    int i;
-    int j; 
-    int hi;
+// a function for populating the loudness matrix with a signal x
+matrix loudness(vector x, vector fERBs, double nyquist, int w, int w2) {
+    int i, j, hi; 
     int offset = 0;
-    double td = nyquist / w2; // This is equivalent to fstep
-
-    // Testing showed this configuration of fftw to be fastest
+    double td = nyquist / w2; // this is equivalent to fstep
+    // testing showed this configuration of fftw to be fastest
 #if 0
     double* fi = fftw_malloc(sizeof(double) * w); 
     fftw_complex* fo = fftw_malloc(sizeof(fftw_complex) * w);
     fftw_plan plan = fftw_plan_dft_r2c_1d(w, fi, fo, FFTW_ESTIMATE); 
 #else
-    double* fi = malloc(sizeof(double) * w); 
+    double* fi = malloc(sizeof(double) * w);
     out_complex* fo = malloc(sizeof(out_complex) * w);
-    vector f;
-    matrix L;
 #endif
-    vector hann = makev(w); // This defines the Hann[ing] window
-    for (i = 0; i < w; i++) {
+    vector hann = makev(w); // this defines the Hann[ing] window
+    for (i = 0; i < w; i++) 
         hann.v[i] = .5 - (.5 * cos(2. * M_PI * ((double) i / w)));
-    }
-#if 0
     vector f = makev(w2);
-#else
-    f = makev(w2);
-#endif
-    for (i = 0; i < w2; i++) f.v[i] = i * td;
-    hi = bisectv(f, fERBs.v[0]); // All calls to La() will begin here
-#if 0
+    for (i = 0; i < w2; i++) 
+        f.v[i] = i * td;
+    hi = bisectv(f, fERBs.v[0]); // all calls to La() will begin here
     matrix L = makem(ceil((double) x.x / w2) + 1, fERBs.x); 
-#else
-    L = makem(ceil((double) x.x / w2) + 1, fERBs.x); 
-#endif
-    for (j = 0; j < w2; j++) { // Left boundary case
-        fi[j] = 0.; // More explicitly, 0. * hann.v[j]
-    }
-    for (/* j = w2 */; j < w; j++) {
+    for (j = 0; j < w2; j++) // left boundary case
+        fi[j] = 0.; // more explicitly, 0. * hann.v[j]
+    for (/* j = w2 */; j < w; j++) 
         fi[j] = x.v[j - w2] * hann.v[j];
-    }
 #if 0
     La(L, f, fERBs, plan, fo, w2, hi, 0); 
-#else 
-    La(L, f, fERBs, fo, w2, hi, 0, fi); 
+#else
+    La(L, f, fERBs, fo, w2, hi, 0, fi);
 #endif
-    for (i = 1; i < L.x - 2; i++) { // Middle case 
-        for (j = 0; j < w; j++) fi[j] = x.v[j + offset] * hann.v[j];
+    for (i = 1; i < L.x - 2; i++) { 
+        for (j = 0; j < w; j++) 
+            fi[j] = x.v[j + offset] * hann.v[j];
 #if 0
         La(L, f, fERBs, plan, fo, w2, hi, i); 
-#else 
-        La(L, f, fERBs, fo, w2, hi, i, fi); 
+#else
+	La(L, f, fERBs, fo, w2, hi, i, fi);
 #endif
         offset += w2;
     }
-    for (/* i = L.x - 2; */; i < L.x; i++) { // Right two boundary cases
-        for (j = 0; j < x.x - offset; j++) { // This dies at x.x + w2
+    for (/* i = L.x - 2; */; i < L.x; i++) { // right two boundary cases
+        for (j = 0; j < x.x - offset; j++) // this dies at x.x + w2
             fi[j] = x.v[j + offset] * hann.v[j];
-        }
-        for (/* j = x.x - offset */; j < w; j++) {
-            fi[j] = 0.; // Once again, 0. * hann.v[j] 
-        }
+        for (/* j = x.x - offset */; j < w; j++) 
+            fi[j] = 0.; // once again, 0. * hann.v[j] 
 #if 0
         La(L, f, fERBs, plan, fo, w2, hi, i);
-#else 
-        La(L, f, fERBs, fo, w2, hi, i, fi); 
+#else
+	La(L, f, fERBs, fo, w2, hi, i, fi);
 #endif
         offset += w2;
-    } // Now L is fully valued
+    } // now L is fully valued
     freev(hann);
     freev(f);
     // L must now be normalized
     for (i = 0; i < L.x; i++) { 
         td = 0.; // td is the value of the normalization factor
-        for (j = 0; j < L.y; j++) td += L.m[i][j] * L.m[i][j];
-        if (td != 0.) { // Catches zero-division
+        for (j = 0; j < L.y; j++) 
+            td += L.m[i][j] * L.m[i][j];
+        if (td != 0.) { // catches zero-division
             td = sqrt(td);
-            for (j = 0; j < L.y; j++) L.m[i][j] /= td;
-        } // Otherwise, it is already 0.
+            for (j = 0; j < L.y; j++) 
+                L.m[i][j] /= td;
+        } // otherwise, it is already 0.
     } 
 #if 0
     fftw_destroy_plan(plan); 
@@ -309,68 +268,50 @@ matrix loudness(vector x, vector fERBs, double nyquist, int w, int w2) { // L
     return(L);
 }
 
-// Populates the strength matrix using the loudness matrix
+// populates the strength matrix using the loudness matrix
 void Sadd(matrix S, matrix L, vector fERBs, vector pci, vector mu, 
                                             intvector ps, double dt, 
-                                                double nyquist2, int lo, 
-                                                    int hi, int psz, int w2) {
-    int i;
-    int j;
-    int k; 
+                                            double nyquist2, int lo, 
+                                            int psz, int w2) {
+    int i, j, k;
     double t = 0.;
     double tp = 0.;
-    double td; 
+    double td;
     double dtp = w2 / nyquist2;
     matrix Slocal = zerom(psz, L.x);
-#if 0
-#else
-    vector q;
-    vector kernel;
-#endif
     for (i = 0; i < Slocal.x; i++) {
-#if 0
         vector q = makev(fERBs.x);
-#else
-        q = makev(fERBs.x);
-#endif
         for (j = 0; j < q.x; j++) q.v[j] = fERBs.v[j] / pci.v[i];
-#if 0
-        vector kernel = zerov(fERBs.x); // A zero-filled kernel vector
-#else
-        kernel = zerov(fERBs.x); // A zero-filled kernel vector
-#endif
+        vector kernel = zerov(fERBs.x); // a zero-filled kernel vector
         for (j = 0; j < ps.x; j++) {
             if PRIME(ps.v[j]) {
                 for (k = 0; k < kernel.x; k++) {
                     td = fabs(q.v[k] - j - 1.); 
-                    if (td < .25) { // Peaks
+                    if (td < .25) // peaks
                         kernel.v[k] = cos(2. * M_PI * q.v[k]);
-                    }
-                    else if (td < .75) { // Valleys
+                    else if (td < .75)  // valleys
                         kernel.v[k] += cos(2. * M_PI * q.v[k]) / 2.;
-                    }
                 }
             }
         }
         freev(q);
         td = 0.; 
         for (j = 0; j < kernel.x; j++) {
-            kernel.v[j] *= sqrt(1. / fERBs.v[j]); // Applying the envelope
-            if (kernel.v[j] > 0.) td += kernel.v[j] * kernel.v[j];
+            kernel.v[j] *= sqrt(1. / fERBs.v[j]); // applying the envelope
+            if (kernel.v[j] > 0.) 
+                td += kernel.v[j] * kernel.v[j];
         }
-        td = sqrt(td); // Now, td is the p=2 norm factor
-        for (j = 0; j < kernel.x; j++) { // Normalize the kernel
+        td = sqrt(td); // now, td is the p=2 norm factor
+        for (j = 0; j < kernel.x; j++) // normalize the kernel
             kernel.v[j] /= td;
-        }
         for (j = 0; j < L.x; j++) { 
-            for (k = 0; k < L.y; k++) {
+            for (k = 0; k < L.y; k++) 
                 Slocal.m[i][j] += kernel.v[k] * L.m[j][k]; // i.e, kernel' * L
-            } 
         }
         freev(kernel);
     } // Slocal is filled out; time to interpolate
     k = 0; 
-    for (j = 0; j < S.y; j++) { // Determine the interpolation params 
+    for (j = 0; j < S.y; j++) { // determine the interpolation params 
         td = t - tp; 
         while (td >= 0.) {
             k++;
@@ -386,15 +327,15 @@ void Sadd(matrix S, matrix L, vector fERBs, vector pci, vector mu,
     freem(Slocal);
 }
 
-// Helper function for populating the strenght matrix on left boundary
+// helper function for populating the strength matrix on left boundary
 void Sfirst(matrix S, vector x, vector pc, vector fERBs, vector d, 
                                            intvector ws, intvector ps, 
-                                               double nyquist, double nyquist2,
-                                                  double dt, int n) {
+                                           double nyquist, double nyquist2,
+                                           double dt, int n) {
     int i; 
     int w2 = ws.v[n] / 2;
     matrix L = loudness(x, fERBs, nyquist, ws.v[n], w2);
-    int lo = 0; // The start of Sfirst-specific code
+    int lo = 0; // the start of Sfirst-specific code
     int hi = bisectv(d, 2.);
     int psz = hi - lo;
     vector mu = makev(psz);
@@ -402,21 +343,21 @@ void Sfirst(matrix S, vector x, vector pc, vector fERBs, vector d,
     for (i = 0; i < hi; i++) {
         pci.v[i] = pc.v[i];
         mu.v[i] = 1. - fabs(d.v[i] - 1.);
-    } // End of Sfirst-specific code
-    Sadd(S, L, fERBs, pci, mu, ps, dt, nyquist2, lo, hi, psz, w2); 
+    } // end of Sfirst-specific code
+    Sadd(S, L, fERBs, pci, mu, ps, dt, nyquist2, lo, psz, w2); 
     freem(L);
     freev(mu);
     freev(pci); 
 }
 
-// Generic helper function for populating the strength matrix
-void Snth(matrix S, vector x, vector pc, vector fERBs, vector d, intvector ws,
-                                intvector ps, double nyquist, double nyquist2, 
-                                                          double dt, int n) {
+// generic helper function for populating the strength matrix
+void Snth(matrix S, vector x, vector pc, vector fERBs, vector d,
+                              intvector ws, intvector ps, double nyquist, 
+                              double nyquist2, double dt, int n) {
     int i;
     int w2 = ws.v[n] / 2;
     matrix L = loudness(x, fERBs, nyquist, ws.v[n], w2);
-    int lo = bisectv(d, n); // Start of Snth-specific code
+    int lo = bisectv(d, n); // start of Snth-specific code
     int hi = bisectv(d, n + 2);
     int psz = hi - lo;
     vector mu = makev(psz);
@@ -426,21 +367,22 @@ void Snth(matrix S, vector x, vector pc, vector fERBs, vector d, intvector ws,
         pci.v[ti] = pc.v[i];
         mu.v[ti] = 1. - fabs(d.v[i] - (n + 1));
         ti++;
-    } // End of Snth-specific code
-    Sadd(S, L, fERBs, pci, mu, ps, dt, nyquist2, lo, hi, psz, w2); 
+    } // end of Snth-specific code
+    Sadd(S, L, fERBs, pci, mu, ps, dt, nyquist2, lo, psz, w2); 
     freem(L);
     freev(mu);
     freev(pci); 
 }
 
-// Helper function for populating the strength matrix from the right boundary
-void Slast(matrix S, vector x, vector pc, vector fERBs, vector d, intvector ws,
-                               intvector ps, double nyquist, double nyquist2, 
-                                                           double dt, int n) {
+// helper function for populating the strength matrix from the right boundary
+void Slast(matrix S, vector x, vector pc, vector fERBs, vector d, 
+                                          intvector ws, intvector ps, 
+                                          double nyquist, double nyquist2, 
+                                          double dt, int n) {
     int i;
     int w2 = ws.v[n] / 2;
     matrix L = loudness(x, fERBs, nyquist, ws.v[n], w2);
-    int lo = bisectv(d, n); // Start of Slast-specific code
+    int lo = bisectv(d, n); // start of Slast-specific code
     int hi = d.x;
     int psz = hi - lo;
     vector mu = makev(psz);
@@ -450,38 +392,27 @@ void Slast(matrix S, vector x, vector pc, vector fERBs, vector d, intvector ws,
         pci.v[ti] = pc.v[i];
         mu.v[ti] = 1. - fabs(d.v[i] - (n + 1));
         ti++;
-    } // End of Slast-specific code
-    Sadd(S, L, fERBs, pci, mu, ps, dt, nyquist2, lo, hi, psz, w2); 
+    } // end of Slast-specific code
+    Sadd(S, L, fERBs, pci, mu, ps, dt, nyquist2, lo, psz, w2); 
     freem(L);
     freev(mu);
     freev(pci); 
 }
 
-// Peforms polynomial tuning on the strength matrix to determine the pitch
+// performs polynomial tuning on the strength matrix to determine the pitch
 vector pitch(matrix S, vector pc, double st) {
-    int i;
-    int j;
+    int i, j;
     int maxi = -1;
     int search = (int) round((log2(pc.v[2]) - log2(pc.v[0])) / POLYV + 1.);
-    double nftc; 
-    double maxv;
-    double log2pc;
+    double nftc, maxv, log2pc;
     double tc2 = 1. / pc.v[1];
     vector coefs;
     vector s = makev(3);
     vector ntc = makev(3);
-#if 0
-#else
-    vector p;
-#endif
     ntc.v[0] = ((1. / pc.v[0]) / tc2 - 1.) * 2. * M_PI; 
     ntc.v[1] = (tc2 / tc2 - 1.) * 2. * M_PI; 
     ntc.v[2] = ((1. / pc.v[2]) / tc2 - 1.) * 2. * M_PI;
-#if 0
     vector p = makev(S.y);  
-#else
-    p = makev(S.y);
-#endif
     for (j = 0; j < S.y; j++) {
         maxv = SHRT_MIN;  
         for (i = 0; i < S.x; i++) {
@@ -490,9 +421,9 @@ vector pitch(matrix S, vector pc, double st) {
                 maxi = i;
             }
         }
-        if (maxv > st) { // Make sure it's big enough
+        if (maxv > st) { // make sure it's big enough
             if (maxi == 0 || maxi == S.x - 1) p.v[j] = pc.v[0];
-            else { // Generic case
+            else { // general case
                 tc2 = 1. / pc.v[maxi];
                 log2pc = log2(pc.v[maxi - 1]); 
                 s.v[0] = S.m[maxi - 1][j];
@@ -500,169 +431,146 @@ vector pitch(matrix S, vector pc, double st) {
                 s.v[2] = S.m[maxi + 1][j]; 
                 coefs = polyfit(ntc, s, 2); 
                 maxv = SHRT_MIN; 
-                for (i = 0; i < search; i++) { // Check the nftc space
-                    nftc = polyval(coefs, ((1. / pow(2, i * POLYV + log2pc)) / 
-                                                          tc2 - 1) * 2 * M_PI);
+                for (i = 0; i < search; i++) { // check the nftc space
+                    nftc = polyval(coefs, ((1. / pow(2, i * POLYV + 
+                                   log2pc)) / tc2 - 1) * 2 * M_PI);
                     if (nftc > maxv) {
                         maxv = nftc;
                         maxi = i;
                     }
-                } // Now we've got the pitch numbers we need
+                } // now we've got the pitch numbers we need
                 freev(coefs);
                 p.v[j] = pow(2, log2pc + (maxi * POLYV));
             }
         }
+        else 
 #if 0
-        else p.v[j] = NAN;
+            p.v[j] = NAN;
 #else
-        else p.v[j] = 0.0;
-#endif
+	    p.v[j] = 0.0;
+#endif	  
     }
     freev(ntc);
     freev(s);
     return(p);
 }
 
-// Primary utility function for each pitch extraction
+// primary utility function for each pitch extraction
 #if 0
 vector swipe(int fid, double min, double max, double st, double dt) {
 #else
-  void swipe(float_list *input, int length, double samplerate, int frame_shift, double min, double max, double st, int otype) {
+void swipe(float_list *input, int length, double samplerate, int frame_shift, double min, double max, double st, int otype) {
 #endif
     int i; 
     double td = 0.;
 #if 0
     SF_INFO info;
-    SNDFILE* source = sf_open_fd(fid, SFM_READ, &info, TRUE);
-    if (source == NULL || info.sections < 1) return(makev(0)); 
-#else
-    double dt = (double) frame_shift / samplerate;
-    float_list *tmpf;
-    vector x = makev(length);
-    intvector ws;
-    vector pc;
-    vector d;
-    vector fERBs;
-    intvector ps;
-    matrix S;
-    vector p;
-    double nyquist = samplerate / 2.;
-    double nyquist2 = samplerate;
-    double nyquist16 = samplerate * 8.;
-
-    for (i = 0, tmpf = input; tmpf != NULL; i++, tmpf = tmpf->next) 
-      x.v[i] = tmpf->f / 32768.0; // normalized by max_short
-#endif
-#if 0
+    SNDFILE* source = sf_open_fd(fid, SFM_READ, &info, true);
+    if (source == NULL || info.sections < 1) 
+        return(makev(0)); 
     double nyquist = info.samplerate / 2.;
     double nyquist2 = info.samplerate;
     double nyquist16 = info.samplerate * 8.;
 #else
+    double dt = (double) frame_shift / samplerate;
+    double nyquist = samplerate / 2.;
+    double nyquist2 = samplerate;
+    double nyquist16 = samplerate * 8.;
 #endif
     if (max > nyquist) {
         max = nyquist;
-        fprintf(stderr, "Max pitch > Nyquist...max set to %.2f Hz.\n", max);
+        fprintf(stderr, "Max pitch exceeds Nyquist frequency...");
+        fprintf(stderr, "max pitch set to %.2f Hz.\n", max);
     }
     if (dt > nyquist2) {
         dt = nyquist2;
         fprintf(stderr, "Timestep > SR...timestep set to %f.\n", nyquist2);
     }
-#if 0
     intvector ws = makeiv(round(log2((nyquist16) / min) -  
                                 log2((nyquist16) / max)) + 1); 
-#else
-    ws = makeiv(round(log2((nyquist16) / min) -  
-                      log2((nyquist16) / max)) + 1); 
-#endif
-    for (i = 0; i < ws.x; i++) {
+    for (i = 0; i < ws.x; i++)
         ws.v[i] = pow(2, round(log2(nyquist16 / min))) / pow(2, i);
-    }
-#if 0
     vector pc = makev(ceil((log2(max) - log2(min)) / DLOG2P));
     vector d = makev(pc.x);
-#else
-    pc = makev(ceil((log2(max) - log2(min)) / DLOG2P));
-    d = makev(pc.x);
-#endif
     for (i = pc.x - 1; i >= 0; i--) { 
         td = log2(min) + (i * DLOG2P);
         pc.v[i] = pow(2, td);
         d.v[i] = 1. + td - log2(nyquist16 / ws.v[0]); 
     } // td now equals log2(min)
 #if 0
-    vector x = makev(info.frames); // This reads the signal in
+    vector x = makev((int) info.frames); // read in the signal
     sf_read_double(source, x.v, x.x);
-    sf_close(source); // Takes FILE* wavf with it, too
+    sf_close(source); // takes wavf with it, too
+#else
+    vector x = makev(length);
+    float_list *tmpf;
+    for (i = 0, tmpf = input; tmpf != NULL; i++, tmpf = tmpf->next)
+      x.v[i] = tmpf->f / 32768.0; // normalized by max_short
+#endif
     vector fERBs = makev(ceil((hz2erb(nyquist) - 
                                hz2erb(pow(2, td) / 4)) / DERBS));
-#else
-    fERBs = makev(ceil((hz2erb(nyquist) - 
-                        hz2erb(pow(2, td) / 4)) / DERBS));
-#endif
     td = hz2erb(min / 4.);
-    for (i = 0; i < fERBs.x; i++) fERBs.v[i] = erb2hz(td + (i * DERBS));
-#if 0
+    for (i = 0; i < fERBs.x; i++) 
+        fERBs.v[i] = erb2hz(td + (i * DERBS));
     intvector ps = onesiv(floor(fERBs.v[fERBs.x - 1] / pc.v[0] - .75));
-#else
-    ps = onesiv(floor(fERBs.v[fERBs.x - 1] / pc.v[0] - .75));
-#endif
     sieve(ps);
-    ps.v[0] = P; // Hack to make 1 "act" prime...don't ask 
+    ps.v[0] = PR; // hack to make 1 "act" prime...don't ask
 #if 0
-    matrix S = zerom(pc.x, ceil(((double) x.x / nyquist2) / dt)); // Strength
+    matrix S = zerom(pc.x, ceil(((double) x.x / nyquist2) / dt));
 #else
-    S = zerom(pc.x, ceil(((double) x.x / nyquist2) / dt)); // Strength
+    matrix S;
+    if(dt >= nyquist2){
+      S = zerom(pc.x, ceil(((double) x.x / nyquist2) / dt));
+    }else{
+      S = zerom(pc.x, ceil((double) x.x / frame_shift));
+    }
 #endif
     Sfirst(S, x, pc, fERBs, d, ws, ps, nyquist, nyquist2, dt, 0); 
-    for (i = 1; i < ws.x - 1; i++) { // S is updated inline here
+    for (i = 1; i < ws.x - 1; i++) // S is updated inline here
         Snth(S, x, pc, fERBs, d, ws, ps, nyquist, nyquist2, dt, i);
-    } // i is now (ws.x - 1)
+    // i is now (ws.x - 1)
     Slast(S, x, pc, fERBs, d, ws, ps, nyquist, nyquist2, dt, i);
     freev(fERBs); 
     freeiv(ws);
     freeiv(ps);
     freev(d);  
     freev(x);
-#if 0
-    vector p = pitch(S, pc, st); // Find pitch using strength matrix
-#else
-    p = pitch(S, pc, st); // Find pitch using strength matrix
-#endif
+    vector p = pitch(S, pc, st); // find pitch using strength matrix
     freev(pc);
     freem(S);
 #if 0
     return(p);
-#else 
+#else
     for (i = 0; i < p.x; i++) {
-       switch(otype) {
-          case 1:      /* f0 */
-             fwritef(&p.v[i], sizeof(p.v[i]), 1, stdout);
-             break;
-          case 2:      /* log(f0) */
-             if (p.v[i] != 0.0)
-                p.v[i] = log(p.v[i]);
-             else
-                p.v[i] = -1.0E10;
-             fwritef(&p.v[i], sizeof(p.v[i]), 1, stdout);
-             break;
-          default:     /* pitch */
-             if (p.v[i] != 0.0)
-                p.v[i] = samplerate / p.v[i];
-             fwritef(&p.v[i], sizeof(p.v[i]), 1, stdout);
-             break;
-       }
+      switch(otype) {
+      case 1:      /* f0 */
+	fwritef(&p.v[i], sizeof(p.v[i]), 1, stdout);
+	break;
+      case 2:      /* log(f0) */
+	if (p.v[i] != 0.0)
+	  p.v[i] = log(p.v[i]);
+	else
+	  p.v[i] = -1.0E10;
+	fwritef(&p.v[i], sizeof(p.v[i]), 1, stdout);
+	break;
+      default:     /* pitch */
+	if (p.v[i] != 0.0)
+	  p.v[i] = samplerate / p.v[i];
+	fwritef(&p.v[i], sizeof(p.v[i]), 1, stdout);
+	break;
+      }
     }
     freev(p);
 #endif
 }
 
 #if 0
+// a Python version of the call
 vector pyswipe(char wav[], double min, double max, double st, double dt) {
     return swipe(fileno(fopen(wav, "r")), min, max, st, dt);
 }
 
-// Function for printing the pitch vector returned by swipe()
-
+// function for printing the pitch vector returned by swipe()
 void printp(vector p, int fid, double dt, int mel, int vlo) {
     int i;
     double t = 0.; 
@@ -676,9 +584,8 @@ void printp(vector p, int fid, double dt, int mel, int vlo) {
         }
         else { // Default case
             for (i = 0; i < p.x; i++) {
-                if (!isnan(p.v[i])) {
+                if (!isnan(p.v[i]))
                     fprintf(sink, "%4.4f %5.4f\n", t, hz2mel(p.v[i])); 
-                }
                 t += dt;
             }
         }
@@ -692,28 +599,29 @@ void printp(vector p, int fid, double dt, int mel, int vlo) {
         }
         else { 
             for (i = 0; i < p.x; i++) {
-                if (!isnan(p.v[i])) fprintf(sink, "%4.4f %5.4f\n", t, p.v[i]); 
+                if (!isnan(p.v[i])) 
+                    fprintf(sink, "%4.4f %5.4f\n", t, p.v[i]);
                 t += dt;
             }
         }
     } 
 }
 
-// Main method, interfacing with user arguments
+// main method, interfacing with user arguments
 int main(int argc, char* argv[]) {
     char output[] = "OUTPUT:\npitch_0\ttime_0\npitch_1\ttime_1\n...\t...\
     \npitch_N\ttime_N\n\n"; 
-    char header[] = "SWIPE' pitch tracker, implemented in C by Kyle Gorman \
-<kgorman@ling.upenn.edu>.\nBased on: Camacho, Arturo (2007). A sawtooth \
+    char header[] = "\nSWIPE' pitch tracker, implemented by Kyle Gorman \
+<gormanky@ohsu.edu>, \nbased on: A. Camacho. 2007. A sawtooth \
 waveform inspired pitch estimator\nfor speech and music. Doctoral \
-dissertation, University of Florida.\n\n\
-\tmore information: <http://ling.upenn.edu/~kgorman/c/swipe/>\n\n";
+dissertation, U of Florida.\n\n\
+More information: <http://ling.upenn.edu/~kgorman/C/swipe/>\n\n";
     char synops[] = "SYNPOSIS:\n\n\
-swipe [-i FILE] [-b LIST] [-o FILE] [-r MIN:MAX] [-s TS] [-t DT] [-mnhv]\n\n\
-FLAG:\t\tDESCRIPTION:\t\t\t\t\tDEFAULT:\n\n\
--i FILE\t\tinput file\t\t\t\t\tSTDIN\n\
--o FILE\t\toutput file\t\t\t\t\tSTDOUT\n\
--b LIST\t\tbatch mode: [LIST is a file containing\n\
+swipe [-i FILE] [-o FILE] [-b LIST] [-r MIN:MAX] [-s TS] [-t DT] [-mnhv]\n\
+\nFLAG:\t\tDESCRIPTION:\t\t\t\t\tDEFAULT:\n\n\
+-i FILE\t\tinput file\t\t\t\t\t<STDIN>\n\
+-o FILE\t\toutput file\t\t\t\t\t<STDOUT>\n\
+-b LIST\t\tbatch mode [LIST is a file containing\n\
 \t\tone \"INPUT OUTPUT\" pair per line]\n\n\
 -r MIN:MAX\tpitchrange in Hertz\t\t\t\t100:600\n\
 -s TIMESTEP\ttimestep in seconds\t\t\t\t0.001\n\
@@ -722,46 +630,57 @@ FLAG:\t\tDESCRIPTION:\t\t\t\t\tDEFAULT:\n\n\
 -n\t\tDon't output voiceless frames\t\t\tno\n\
 -h\t\tDisplay this message, then quit\n\
 -v\t\tDisplay version number, then quit\n\n";
-    double st = ST; // All set by #defines
+    // all set by #defines
+    double st = ST; 
     double dt = DT;
-    int vlo = TRUE;
-    int mel = FALSE; 
+    bool vlo = true;
+    bool mel = false;
     double min = MIN;
     double max = MAX; 
     int ch;
     FILE* batch = NULL; // not going to be read that way,
-    /* 
-     * initialize the char[] as "\0"-initial. This is done automatically by 
-     * Linux tools, but not always by Mac OS X, I find.
-     */
-    char wav[FILENAME_MAX] = "\0";
-    char out[FILENAME_MAX] = "\0";
+    // some, but not all, compilers initialize char*s to be "\0"
+    char* wav = "\0"; 
+    char* out = "\0";
+    int needed;
     while ((ch = getopt(argc, argv, "i:o:r:s:t:b:mnhv")) != -1) {
         switch(ch) {
             case 'b':
-                batch = fopen(optarg, "r"); 
+                batch = fopen(optarg, "r");
                 break;
             case 'i':
+                needed = (int) strlen(optarg);
+                if (needed > FILENAME_MAX) {
+                    fprintf(stderr, "Filename too long, aborting.\n");
+                    exit(EXIT_FAILURE);
+                }
+                wav = (char *) malloc(sizeof(char) * needed);
                 strcpy(wav, optarg);
                 break; 
             case 'o':
-                strcpy(out, optarg); 
+                needed = (int) strlen(optarg);
+                if (needed > FILENAME_MAX) {
+                    fprintf(stderr, "Filename too long, aborting.\n");
+                    exit(EXIT_FAILURE);
+                }
+                out = (char *) malloc(sizeof(char) * needed);
+                strcpy(out, optarg);
                 break;
             case 'r':
                 min = atof(strtok(optarg, ":"));
                 max = atof(strtok(NULL, ":")); 
                 break;
-            case 's':
+            case 't':
                 st = atof(optarg);
                 break;
-            case 't':
+            case 's':
                 dt = atof(optarg);
                 break;
             case 'm':
-                mel = TRUE; 
+                mel = true; 
                 break;
             case 'n':
-                vlo = FALSE; 
+                vlo = false; 
                 break;
             case 'h':
                 fprintf(stderr, "%s", header); 
@@ -771,8 +690,8 @@ FLAG:\t\tDESCRIPTION:\t\t\t\t\tDEFAULT:\n\n\
             case 'v':
                 fprintf(stderr, "This is SWIPE', v. %1.1f.\n", VNUM); 
                 exit(EXIT_SUCCESS);
-            case '?': 
-            default:  // Would like to do clever things here, but no ideas yet
+            case '?':
+            default: 
                 fprintf(stderr, "%s", header);
                 fprintf(stderr, "%s", synops);
                 exit(EXIT_FAILURE);
@@ -780,7 +699,8 @@ FLAG:\t\tDESCRIPTION:\t\t\t\t\tDEFAULT:\n\n\
             argv += optind;
         }
     }
-    if (min < 1.) { // Santiny-check the args
+    // santiny-check the args
+    if (min < 1.) { 
         fprintf(stderr, "Min pitch < 1 Hz, aborting.\n"); 
         exit(EXIT_FAILURE);
     }
@@ -796,9 +716,10 @@ FLAG:\t\tDESCRIPTION:\t\t\t\t\tDEFAULT:\n\n\
         fprintf(stderr, "Timestep must be >= 0.001, set to %.3f.\n", DT);
         dt = DT;
     }
-    if (batch != NULL) { // Iterate through batch pairs
+    if (batch != NULL) { 
+        // iterate through batch pairs
         while (fscanf(batch, "%s %s", wav, out) != EOF) {
-            fprintf(stderr, "%s -> %s...", wav, out);
+            printf("%s -> %s...", wav, out);
             FILE* wf = fopen(wav, "r");
             if (wf == NULL) {
                 fprintf(stderr, "Reading from \"%s\" failed.\n", wav);
@@ -829,29 +750,35 @@ FLAG:\t\tDESCRIPTION:\t\t\t\t\tDEFAULT:\n\n\
         vector p;
         if (*wav == '\0') {
             p = swipe(fileno(stdin), min, max, st, dt);
-            strcpy(wav, "<STDIN>"); // no buffer overflows!
+            wav = "<STDIN>";
         }
         else {
             FILE* input = fopen(wav, "r");
             if (input == NULL) {
-                fprintf(stderr, "Reading from \"%s\" failed.\n", wav);
+                fprintf(stderr, "Reading from \"%s\" failed (try ", wav);
+                fprintf(stderr, "specifying an input file with -i).\n");
                 exit(EXIT_FAILURE);
             }
             p = swipe(fileno(input), min, max, st, dt);
         }
         if (p.x == NOK) {
-            if (*wav == '\0') fprintf(stderr, "Reading from STDIN failed.\n");
-            else fprintf(stderr, "Reading from \"%s\" failed.\n", wav);
+            if (*wav == '\0') {
+                fprintf(stderr, "Reading from STDIN failed (did ");
+                fprintf(stderr, "you pipe a file to `swipe`?').\n");
+            }
+            else {
+                fprintf(stderr, "Reading from \"%s\" failed (try ", wav);
+                fprintf(stderr, "specifying an input file with -i).\n");
+            }
             exit(EXIT_FAILURE);
         }
         else {
-            if (*out == '\0') {
+            if (*out == '\0') 
                 printp(p, fileno(stdout), dt, mel, vlo);
-            }
             else {
                 FILE* output = fopen(out, "w");
                 if (output == NULL) {
-                    fprintf(stderr, "Writing to \"%s\" failed", out);
+                    fprintf(stderr, "Writing to \"%s\" failed.\n", out);
                     exit(EXIT_FAILURE);
                 }
                 printp(p, fileno(output), dt, mel, vlo);
@@ -861,4 +788,4 @@ FLAG:\t\tDESCRIPTION:\t\t\t\t\tDEFAULT:\n\n\
     }
     exit(EXIT_SUCCESS);
 }
-#endif /* 0 */
+#endif
