@@ -8,7 +8,7 @@
 /*                           Interdisciplinary Graduate School of    */
 /*                           Science and Engineering                 */
 /*                                                                   */
-/*                1996-2013  Nagoya Institute of Technology          */
+/*                1996-2014  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -43,7 +43,7 @@
 /* ----------------------------------------------------------------- */
 
 /***********************************************************
-   $Id: SPTK.h,v 1.54 2013/12/16 09:02:06 mataki Exp $ 
+   $Id: SPTK.h,v 1.60 2014/12/11 08:30:52 uratec Exp $ 
    
    Speech Signal Processing Toolkit
    SPTK.h
@@ -125,6 +125,31 @@ typedef struct _deltawindow {
    double **win_coefficient;
 } DELTAWINDOW;
 
+/* structure for wavsplit and wavjoin */
+typedef struct _wavfile {
+   int file_size;               /* file size */
+   int fmt_chunk_size;          /* size of 'fmt ' chunk (byte) */
+   int data_chunk_size;         /* size of 'data' chunk (byte) */
+   short format_id;             /* format ID (PCM(1) or IEEE float(3)) */
+   short channel_num;           /* mono:1stereo:2 */
+   int sample_freq;             /* sampling frequency (Hz) */
+   int byte_per_sec;            /* byte per second */
+   short block_size;            /* 16bit, mono => 16bit*1=2byte */
+   short bit_per_sample;        /* bit per sample */
+   short extended_size;         /* size of 'extension' */
+
+   char input_data_type;
+   char format_type;
+
+   char *data;                  /* waveform data */
+
+} Wavfile;
+
+typedef struct _filelist {
+   int num;
+   char **name;
+} Filelist;
+
 /* library routines */
 double agexp(double r, double x, double y);
 int cholesky(double *c, double *a, double *b, const int n, double eps);
@@ -175,6 +200,7 @@ void vaverage(double *x, const int l, const int num, double *ave);
 void b2mc(double *b, double *mc, int m, const double a);
 void c2acr(double *c, const int m1, double *r, const int m2, const int flng);
 void c2ir(double *c, const int nc, double *h, const int leng);
+void c2ndps(double *c, const int m, double *n, const int l);
 void ic2ir(double *h, const int leng, double *c, const int nc);
 void c2sp(double *c, const int m, double *x, double *y, const int l);
 void clip(double *x, const int l, const double min, const double max,
@@ -219,6 +245,10 @@ int alloc_GMM(GMM * gmm, const int M, const int L, const Boolean full);
 int load_GMM(GMM * gmm, FILE * fp);
 int save_GMM(const GMM * gmm, FILE * fp);
 int free_GMM(GMM * gmm);
+int prepareCovInv_GMM(GMM * gmm);
+int prepareGconst_GMM(GMM * gmm);
+int floorWeight_GMM(GMM * gmm, double floor);
+int floorVar_GMM(GMM * gmm, double floor);
 void gnorm(double *c1, double *c2, int m, const double g);
 void grpdelay(double *x, double *gd, const int size, const int is_arma);
 int histogram(double *x, const int size, const double min, const double max,
@@ -275,6 +305,8 @@ void mgc2mgc(double *c1, const int m1, const double a1, const double g1,
              double *c2, const int m2, const double a2, const double g2);
 void mgc2sp(double *mgc, const int m, const double a, const double g, double *x,
             double *y, const int flng);
+void mgclsp2sp(double a, double g, double *lsp, const int m, double *x,
+               const int l, const int gain);
 int mgcep(double *xw, int flng, double *b, const int m, const double a,
           const double g, const int n, const int itr1, const int itr2,
           const double dd, const int etype, const double e, const double f,
@@ -297,6 +329,7 @@ double mlsadft(double x, double *b, const int m, const double a, const int pd,
                double *d);
 void msvq(double *x, double *cb, const int l, int *cbsize, const int stage,
           int *index);
+void ndps2c(double *n, const int l, double *c, const int m);
 void norm0(double *x, double *y, int m);
 int nrand(double *p, const int leng, const int seed);
 double nrandom(unsigned long *next);
@@ -333,3 +366,15 @@ double zerodf(double x, double *b, int m, double *d);
 double zerodft(double x, double *b, const int m, double *d);
 double zerodf1(double x, double *b, int m, double *d);
 double zerodf1t(double x, double *b, const int m, double *d);
+
+/* wavsplit and wavjoin */
+void copy_wav_header(Wavfile * dest_wav, const Wavfile * source_wav);
+void separate_path(char **dir, char **name, char *path);
+Boolean get_wav_list(Filelist * filelist, const char *dirname);
+Boolean wavread(Wavfile * wavfile, const char *fullpath);
+Boolean wavwrite(Wavfile * wavfile, const char *outpath);
+void wavsplit(Wavfile * wavout, const Wavfile * wavin);
+void free_wav_list(Filelist * filelist);
+void free_wav_data(Wavfile * wavfile);
+void wavjoin(Wavfile * wavout, const Wavfile * wavin);
+int search_wav_list(Filelist * filelist, char *key);
